WsClientBuilder

Struct WsClientBuilder 

pub struct WsClientBuilder { /* private fields */ }
Builder for WsClient.

Examples


use jsonrpsee_ws_client::{WsClientBuilder, HeaderMap, HeaderValue};

#[tokio::main]
async fn main() {
    // Build custom headers used during the handshake process.
    let mut headers = HeaderMap::new();
    headers.insert("Any-Header-You-Like", HeaderValue::from_static("42"));

    // Build client
    let client = WsClientBuilder::default()
         .set_headers(headers)
         .build("wss://localhost:443")
         .await
         .unwrap();

    // use client....
}

Implementations

Source

impl WsClientBuilder

pub fn certificate_store( self, certificate_store: CertificateStore, ) -> WsClientBuilder

See documentation WsTransportClientBuilder::certificate_store (default is native).

pub fn max_request_body_size(self, size: u32) -> WsClientBuilder

See documentation WsTransportClientBuilder::max_request_body_size (default is 10 MB).

pub fn request_timeout(self, timeout: Duration) -> WsClientBuilder

See documentation ClientBuilder::request_timeout (default is 60 seconds).

pub fn connection_timeout(self, timeout: Duration) -> WsClientBuilder

See documentation WsTransportClientBuilder::connection_timeout (default is 10 seconds).

pub fn ping_interval(self, interval: Duration) -> WsClientBuilder

See documentation ClientBuilder::ping_interval (disabled by default).

pub fn set_headers(self, headers: HeaderMap) -> WsClientBuilder

See documentation WsTransportClientBuilder::set_headers (default is none).

pub fn max_concurrent_requests(self, max: usize) -> WsClientBuilder

See documentation ClientBuilder::max_concurrent_requests (default is 256).

pub fn max_notifs_per_subscription(self, max: usize) -> WsClientBuilder

See documentation ClientBuilder::max_notifs_per_subscription (default is 1024).

pub fn max_redirections(self, redirect: usize) -> WsClientBuilder

See documentation WsTransportClientBuilder::max_redirections (default is 5).

pub fn id_format(self, kind: IdKind) -> WsClientBuilder

See documentation for ClientBuilder::id_format (default is Number).

pub async fn build(self, url: impl AsRef<str>) -> Result<Client, Error>

Build the client with specified URL to connect to. You must provide the port number in the URL.

Panics

Panics if being called outside of tokio runtime context.